branch: externals/queue
commit 442799876b16b1826ca94584dd199caaa4de145e
Author: Toby S. Cubitt <toby-predict...@dr-qubit.org>
Commit: Toby S. Cubitt <toby-predict...@dr-qubit.org>

    Added autoload cookies.
---
 queue.el | 7 ++++++-
 1 file changed, 6 insertions(+), 1 deletion(-)

diff --git a/queue.el b/queue.el
index b7a1ade..279a355 100644
--- a/queue.el
+++ b/queue.el
@@ -32,7 +32,7 @@
 ;; first-in first-out (FIFO) stack, i.e. elements can be added to and
 ;; removed from the front or back of the queue.
 ;;
 ;; Yoy create a queue using `queue-create', add an element to the end of
 ;; the queue using `queue-enqueue', and push an element onto the front
 ;; of the queue using `queue-prepend'. To remove the first element from
 ;; a queue, use `queue-dequeue'. A number of other queue convenience
@@ -56,6 +56,11 @@
   head tail)
 
 
+;;;###autoload
+(defalias 'make-queue 'queue-create
+  "Create an empty queue data structure.")
+
+
 (defun queue-enqueue (queue element)
   "Append an ELEMENT to the end of the QUEUE."
   (if (queue-head queue)
@@ -32,7 +32,7 @@
 ;; removed from the front or back of the queue.
 ;;
-;; Yoy create a queue using `queue-create', add an element to the end of
+;; You create a queue using `make-queue', add an element to the end of
 ;; the queue using `queue-enqueue', and push an element onto the front
 ;; of the queue using `queue-prepend'. To remove the first element from

Reply via email to